use phf::phf_set;

/// An assembly token.
#[derive(Debug, PartialEq, Clone)]
pub enum Token {
    /// An instruction in the given instruction set.
    Instruction(String),

    /// The `,` character.
    Comma,

    /// A base-10 unsigned integer literal.
    DecimalLiteral(u64),
}

/// A `Token` with source position information.
#[derive(Debug, PartialEq, Clone)]
pub struct TokenInfo {
    /// The `Token`.
    pub token: Token,

    /// The line in the source.
    pub line: usize,

    /// The column in the source where the token started.
    pub column: usize,
}

/// All currently supported instructions.
pub const INSTRUCTIONS: phf::Set<&'static str> = phf_set! {
    "db",
    "dw",
    "dd",
    "dq"
};
